package com.tnkfactory.offerwallsample;

import android.app.Activity;
import android.content.Intent;
import android.content.res.Configuration;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;
import android.widget.Button;

import com.tnkfactory.ad.TnkLayout;
import com.tnkfactory.ad.TnkSession;
import com.tnkfactory.ad.TnkStyle;

/**
 * Created by tnk on 2018-03-29.
 */

public class MainActivity extends Activity {

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main_layout);

        if (TnkSession.getUserName(getApplicationContext()) == null) {
            TnkSession.setUserName(getApplicationContext(), "tnk_" + System.currentTimeMillis());
        }

        // showAdList use AdWallActivity
        Button adListActivity = (Button) findViewById(R.id.main_ad_custom);
        adListActivity.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                TnkSession.showAdList(MainActivity.this, "Your title here", makeTnkLayout());
            }
        });

        // showAdList Embed
        Button adListEmbed = (Button) findViewById(R.id.main_ad_custom_embed);
        adListEmbed.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(MainActivity.this, EmbedActivity.class);
                intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP|Intent.FLAG_ACTIVITY_SINGLE_TOP);
                startActivity(intent);
            }
        });

        // showAdList Popup
        Button adListPopup = (Button) findViewById(R.id.main_ad_custom_popup);
        adListPopup.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                TnkSession.popupAdList(MainActivity.this,"Your title here", null, makePopupTnkLayout());
            }
        });
    }

    private TnkLayout makeTnkLayout() {
        TnkLayout res = new TnkLayout();

        res.adwall.numColumnsPortrait = 1;
        res.adwall.numColumnsLandscape = 2;

        res.adwall.layout = R.layout.offerwall_adlist;
        res.adwall.idTitle = R.id.offerwall_title;
        res.adwall.idList = R.id.offerwall_adlist;

        res.adwall.item.layout = R.layout.offerwall_adlist_item;

        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
            res.adwall.item.height = getResources().getDimensionPixelSize(R.dimen.adlist_item_height_portrait);
        }
        else {
            res.adwall.item.height = getResources().getDimensionPixelSize(R.dimen.adlist_item_height_landscape);
        }

        res.adwall.item.idTitle = R.id.ad_title;
        //res.adwall.item.idSubtitle = R.id.ad_desc;
        res.adwall.item.idTag = R.id.ad_tag;
        res.adwall.item.colorBg = 0xffe5e5e5;
        res.adwall.item.idCampnType = R.id.ad_campaign_type;

        res.adwall.item.idImage = R.id.ad_image;
        res.adwall.imgType = TnkLayout.IMAGE_LANDSCAPE; // 전면 이미지 종류 지정

        res.adwall.item.tag.pointLabelFormat = "{point}{unit}";

        res.adwall.item.tag.bgTagFree = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagPaid = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagWeb = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagCheck = R.color.ad_tag_bg_color;

        res.adwall.item.tag.tcTagFree = 0xffffffff;
        res.adwall.item.tag.tcTagPaid = 0xffffffff;
        res.adwall.item.tag.tcTagWeb = 0xffffffff;
        res.adwall.item.tag.tcTagCheck = 0xffffffff;

        setTnkStyle();

        return res;
    }

    private TnkLayout makePopupTnkLayout() {
        TnkLayout res = new TnkLayout();

        res.adwall.numColumnsPortrait = 1;
        res.adwall.numColumnsLandscape = 2;

        res.adwall.layout = R.layout.offerwall_popup;
        res.adwall.idTitle = R.id.offerwall_title;
        res.adwall.idList = R.id.offerwall_adlist;
        res.adwall.idClose = R.id.close_button;

        res.adwall.item.layout = R.layout.offerwall_popup_item;

        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT) {
            res.adwall.item.height = getResources().getDimensionPixelSize(R.dimen.adlist_popup_item_height_portrait);
        }
        else {
            res.adwall.item.height = getResources().getDimensionPixelSize(R.dimen.adlist_popup_item_height_landscape);
        }

        res.adwall.item.idTitle = R.id.ad_title;
        //res.adwall.item.idSubtitle = R.id.ad_desc;
        res.adwall.item.idTag = R.id.ad_tag;
        res.adwall.item.idCampnType = R.id.ad_campaign_type;

        res.adwall.item.idImage = R.id.ad_image;
        res.adwall.imgType = TnkLayout.IMAGE_LANDSCAPE; // 전면 이미지 종류 지정

        res.adwall.item.tag.pointLabelFormat = "{point}{unit}";

        res.adwall.item.tag.bgTagFree = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagPaid = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagWeb = R.color.ad_tag_bg_color;
        res.adwall.item.tag.bgTagCheck = R.color.ad_tag_bg_color;

        res.adwall.item.tag.tcTagFree = 0xffffffff;
        res.adwall.item.tag.tcTagPaid = 0xffffffff;
        res.adwall.item.tag.tcTagWeb = 0xffffffff;
        res.adwall.item.tag.tcTagCheck = 0xffffffff;

        setTnkStyle();

        return res;
    }

    private void setTnkStyle() {

        TnkStyle.AdWall.showCloseButton = false;
        TnkStyle.AdWall.showFooter = false;

        // 리스트 아이템 캠페인 타입 리소스 설정
        TnkStyle.AdWall.Item.CampnType.Install.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Install.textColor = 0xff1387da;
        TnkStyle.AdWall.Item.CampnType.Install.background = R.drawable.campaign_label_01;
        TnkStyle.AdWall.Item.CampnType.Run.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Run.textColor = 0xffff4b50;
        TnkStyle.AdWall.Item.CampnType.Run.background = R.drawable.campaign_label_02;
        TnkStyle.AdWall.Item.CampnType.Action.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Action.textColor = 0xffff6100;
        TnkStyle.AdWall.Item.CampnType.Action.background = R.drawable.campaign_label_03;
        TnkStyle.AdWall.Item.CampnType.Reservation.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Reservation.textColor = 0xff51c701;
        TnkStyle.AdWall.Item.CampnType.Reservation.background = R.drawable.campaign_label_04;
        TnkStyle.AdWall.Item.CampnType.SNS.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.SNS.textColor = 0xff421ee0;
        TnkStyle.AdWall.Item.CampnType.SNS.background = R.drawable.campaign_label_05;
        TnkStyle.AdWall.Item.CampnType.Join.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Join.textColor = 0xffca0006;
        TnkStyle.AdWall.Item.CampnType.Join.background = R.drawable.campaign_label_06;
        TnkStyle.AdWall.Item.CampnType.Video.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Video.textColor = 0xff00b293;
        TnkStyle.AdWall.Item.CampnType.Video.background = R.drawable.campaign_label_07;
        TnkStyle.AdWall.Item.CampnType.Etc.textSize = getResources().getInteger(R.integer.adlist_item_campn_type_size);
        TnkStyle.AdWall.Item.CampnType.Etc.textColor = 0xff696969;
        TnkStyle.AdWall.Item.CampnType.Etc.background = R.drawable.campaign_label_08;
    }
}
